@@ -62,7 +62,7 @@ public:
     /**
      * Destructor.
      */
-    ~SearchBarCombo();
+    ~SearchBarCombo() override;
 
     /**
      * Returns the icon currently displayed in the combo box.
@@ -98,7 +98,7 @@ public:
     void setSuggestionItems(const QStringList &suggestions);
 
     /**
-     * Clear all presviously set suggestion items for this ComboBox
+     * Clear all previously set suggestion items for this ComboBox
      */
     void clearSuggestions();
 
@@ -118,7 +118,7 @@ protected:
      * Captures mouse clicks and emits iconClicked() if the icon
      * was clicked.
      */
-    void mousePressEvent(QMouseEvent *e) Q_DECL_OVERRIDE;
+    void mousePressEvent(QMouseEvent *e) override;
 
 private Q_SLOTS:
     void historyCleared();
@@ -148,10 +148,10 @@ public:
 
     SearchBarPlugin(QObject *parent,
                     const QVariantList &);
-    virtual ~SearchBarPlugin();
+    ~SearchBarPlugin() override;
 
 protected:
-    bool eventFilter(QObject *o, QEvent *e) Q_DECL_OVERRIDE;
+    bool eventFilter(QObject *o, QEvent *e) override;
 
 private Q_SLOTS:
     /**
@@ -234,8 +234,8 @@ private:
 class SearchBarItemDelegate : public QItemDelegate
 {
 public:
-    SearchBarItemDelegate(QObject *parent = Q_NULLPTR);
-    void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const Q_DECL_OVERRIDE;
+    SearchBarItemDelegate(QObject *parent = nullptr);
+    void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
 };
 
 #endif // SEARCHBAR_PLUGIN
